<?php
// $Horde: turba/lib/api.php,v 1.14.2.2 2001/11/29 14:46:01 jan Exp $

// Find the base file path of Turba
if (!defined('TURBA_BASE')) define('TURBA_BASE', dirname(__FILE__) . '/..');

// Include the Turba base libraries and setup.
require_once TURBA_BASE . '/lib/base.php';

function turbaExpandAddresses($names = array(), $addressbooks = array(), $fields = array())
{
    include TURBA_BASE . '/config/sources.php';
    include TURBA_BASE . '/config/attributes.php';
    include_once TURBA_BASE . '/lib/Source.php';

    if (!isset($cfgSources) || !is_array($cfgSources) || !count($cfgSources)) {
        return array();
    }

    if (count($addressbooks) == 0) {
        $addressbooks = array(key($cfgSources));
    }

    $results = array();
    $seen = array();
    foreach ($addressbooks as $source) {
        if (isset($cfgSources[$source])) {
            $driver = Turba_Source::factory($source, $cfgSources[$source]);
            if (PEAR::isError($driver)) {
                return new PEAR_Error(_("Failed to connect to the specified directory."));
            }
            
            foreach ($names as $name) {
                $criteria = array();
                if (isset($fields[$source])) {
                    foreach ($fields[$source] as $field) {
                        $criteria[$field] = trim($name);
                    }
                }
                if (count($criteria) == 0) {
                    $criteria['name'] = trim($name);
                }
                $res = $driver->search($criteria, LASTNAME, TURBA_SEARCH_OR);
                if (!isset($results[$name])) {
                    $results[$name] = array();
                }
                if (get_class($res) == 'turba_list') {
                    while ($ob = $res->next()) {
                        $att = $ob->getAttributes();
                        foreach ($att as $key => $value) {
                            if (!empty($value) && isset($attributes[$key]) &&
                                $attributes[$key]['type'] == 'email' &&
                                empty($seen[$name][trim(strtolower($att['name'])) . trim(strtolower($value))])) {
                                
                                $results[$name][] = array('name' => $att['name'], 'email' => $value);
                                $seen[$name][trim(strtolower($att['name'])) . trim(strtolower($value))] = true;
                            }
                        }
                    }
                }
            }
            
        }
    }
    
    return $results;
}

function turbaAddAddress($name = '', $address = '', $addressbook = '')
{
    include TURBA_BASE . '/config/sources.php';
    include_once 'PEAR.php';
    include_once TURBA_BASE . '/lib/Source.php';

    if (empty($addressbook) || !isset($cfgSources[$addressbook])) {
        return PEAR::raiseError(_("Invalid addressbook."));
    }

    if (empty($name)) {
        return PEAR::raiseError(_("Invalid name."));
    }

    if (empty($address)) {
        return PEAR::raiseError(_("Invalid e-mail address."));
    }

    if ($cfgSources[$addressbook]['readonly']) {
        return PEAR::raiseError(_("Addressbook is read-only."));
    }

    $driver = Turba_Source::factory($addressbook, $cfgSources[$addressbook]);
    return $driver->addObject(array('name' => $name, 'email' => $address, '__owner' => Auth::getAuth()));
}

function turbaGetSources($writeable = false)
{
    include TURBA_BASE . '/config/sources.php';
    include_once 'PEAR.php';

    if (!isset($cfgSources) || !is_array($cfgSources) || !count($cfgSources)) {
        return array();
    }

    $readonly = array();
    $writeonly = array();

    foreach ($cfgSources as $key => $entry) {
        if ($entry['readonly']) {
            $readonly[$key] = $entry['title'];
        } else {
            $writeonly[$key] = $entry['title'];
        }
    }

    if ($writeable) {
        return $writeonly;
    } else {
        return array_merge($readonly, $writeonly);
    }
}

function turbaGetFields($addressbook = '')
{
    include TURBA_BASE . '/config/sources.php';
    include TURBA_BASE . '/config/attributes.php';
    include_once 'PEAR.php';
    
    if (empty($addressbook) || !isset($cfgSources[$addressbook])) {
        return PEAR::raiseError(_("Invalid addressbook."));
    }
    
    $fields = array();
    foreach ($cfgSources[$addressbook]['map'] as $field_name => $null) {
        if (substr($field_name, 0, 2) != '__') {
            $fields[$field_name] = array('name' => $field_name,
                                         'type' => $attributes[$field_name]['type'],
                                         'desc' => $attributes[$field_name]['desc'],
                                         'search' => in_array($field_name, $cfgSources[$addressbook]['search']));
        }
    }
    
    return $fields;
}

?>
